import request from '/@/utils/request';

export function riskWarningApi() {
    return {

        //spi版本分页列表
        getSpiData: (data:number) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/dep/12month?depId=${data}`,
                method: 'get',
            });
        },

        //获取任意部门事故统计指定月度区间报表
        getRiskByTimeDep: (data: {year:string,month: string}) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/accident/count?year=${data.year}&month=${data.month}`,
                method: 'get',
            });
        },

        //获取任意部门应急演练指定月度区间报表
        getEmergencyByDep: (data: {depId:number,beginYear:string,beginMonth:string,endYear: string,endMonth:string}) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/risk/report/multipleMonth/emergency/department?depId=${data.depId}&beginYear=${data.beginYear}&beginMonth=${data.beginMonth}&endYear=${data.endYear}&endMonth=${data.endMonth}`,
                method: 'get',
            });
        },

        //获取任意部门的双重预防隐患指定月份区间报表
        getSelfPreventByTimeDep: (data: {depId:number,beginYear:string,beginMonth:string,endYear: string,endMonth:string}) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/risk/report/multipleMonth/prevent/department?depId=${data.depId}&beginYear=${data.beginYear}&beginMonth=${data.beginMonth}&endYear=${data.endYear}&endMonth=${data.endMonth}`,
                method: 'get',
            });
        },

        //获取任意部门的直属子部门的双重预防隐患指定月份区间报表
        getPreventByTimeDep: (data: {depId:number,beginYear:string,beginMonth:string,endYear: string,endMonth:string}) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/risk/report/multipleMonth/prevent/subDepartments?depId=${data.depId}&beginYear=${data.beginYear}&beginMonth=${data.beginMonth}&endYear=${data.endYear}&endMonth=${data.endMonth}`,
                method: 'get',
            });
        },

        // 人员专业度分析
        getUserCount: () => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/user/count`,
                method: 'get',
            });
        },

        // 教育培训分析
        getTrainInfo: () => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/last/train/info`,
                method: 'get',
            });
        },

        // 应急物资储备
        getEmergencySupplies: () => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/emergency/supplies`,
                method: 'get',
            });
        },

        // 智能巡检超期未巡检
        getSafeCheckTask: () => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/safe/check/task`,
                method: 'get',
            });
        },

        // 隐患趋势
        getDpLine: () => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/dp/line`,
                method: 'get',
            });
        },

        // 隐患等级
        getDpGrade: (params: object) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/dp/grade`,
                method: 'post',
                data: params
            });
        },

        // spi分页
        getSpiPage: (params: object) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/spi/list/Page`,
                method: 'post',
                data: params
            });
        },

        // spi新增
        addSpi: (params: object) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/spi/add`,
                method: 'post',
                data: params
            });
        },

        // spi修改
        modSpi: (params: object) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/spi/mod`,
                method: 'post',
                data: params
            });
        },

        // spi删除
        delSpi: (id: number | null) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/spi/del/${id}`,
                method: 'delete'
            });
        },

        // spi总记录
        getAllReport: () => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/all`,
                method: 'get',
            });
        },

        // spi总记录
        getReportDetails: (id: number | null) => {
            return request({
                url: import.meta.env.VITE_API_URL + `/riskCtrl/spi/report/get/${id}`,
                method: 'get',
            });
        }

    };
}
